ApiPath class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

apiPath → String
no setter
getFileList → String
no setter
getLike → String
no setter
getOpenGraph → String
no setter
getRoomInfo → String
no setter
googleTranslate → String
no setter
like → String
no setter
loadFile → String
no setter
reportUser → String
no setter
saveFile → String
no setter