ChannelMessageModel class

Properties

clientKey → String?
사용자의 client key (unique 값)
final
error ↔ VChatCloudError?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ dynamic
받은 메시지 (보통은 String 또는 Json)
getter/setter pair
messageDt ↔ DateTime
YYYYMMDDHH24MISS 포맷
latefinal
messageType → MessageType?
MessageType
final
mimeType → MimeType?
MimeType
final
nickName ↔ String?
닉네임
getter/setter pair
roomId → String?
채팅방 channel key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userInfo → dynamic
사용자 정보(json)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited