ChannelResultModel class

Constructors

ChannelResultModel.fromJson(Map<String, dynamic> json)

Properties

address → String
final
body → dynamic
final
error ↔ VChatCloudError?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited