ChatRoomModel class

Constructors

ChatRoomModel.fromJson(Map<String, dynamic> json)

Properties

gTransStat ↔ String
구글 번역 사용여부
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lockType ↔ String
방 잠금 유형 (PW: 비밀번호 | EM: 이메일 | ALL: 비밀번호+이메일)
getter/setter pair
prtcRstr ↔ String
방 잠금 여부 (Y/N)
getter/setter pair
roomDestroyYn ↔ String
방 삭제 여부
getter/setter pair
roomNm ↔ String
방 이름
getter/setter pair
roomType ↔ String
방 종류 (01: 채팅 | 02: 영상 | 03: 메타버스)
getter/setter pair
rtcStat ↔ String
rtc 사용 여부
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userEmail ↔ String
방 생성자 이메일
getter/setter pair
userMax ↔ int
최대 접속 가능인원
getter/setter pair
wbrtRslt ↔ int
해상도 설정
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited