UploadFileModel class

Constructors

UploadFileModel({File? file, List<int>? bytes, String? name})

Properties

bytes → List<int>?
final
file → File?
final
hashCode → int
The hash code for this object.
no setterinherited
isByte → bool
no setter
isFile → bool
no setter
name ↔ String
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Future<int>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited