UserModel class

Constructors

UserModel({required String roomId, required String nickName, String? clientKey, String? grade, dynamic userInfo})
UserModel.fromJson(Map<String, dynamic> json)

Properties

clientKey ↔ String
getter/setter pair
grade ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nickName → String
final
roomId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userInfo → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited