VChatCloudError class

Inheritance

Constructors

VChatCloudError(int code, String message)
VChatCloudError.fromCode(int code)
VChatCloudError.fromResult(VChatCloudResult result, {int? code, String? message})

Properties

code ↔ int
latefinal
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited